@@ -17,7 +17,7 @@ grep -v -e '^.TH ' $man.old >> $man
 
 for s in supported_distros supported_other supported_dms supported_wms ; do
 	sed -i "/@${s}_start@/,/@${s}_end@/{/@${s}_start@/!{/@${s}_end@/!d}}" $man
-	list="$(grep "${s}=" $script | cut -d'"' -f2)"
+	list="$(sed -e :a -e '/\\$/N; s/\\\n//; ta' $script | grep "${s}=" | cut -d'"' -f2)"
 	sed -i "s:@${s}_start@:@${s}_start@\n${list}:" $man
 done
 
